=======
Views
=======

Morp inherits its view implementation from Morepath
and it is best to head to `Morepath's view documentation
<https://morepath.readthedocs.io/en/latest/views.html>`_ to get better
understanding on how views work in MorpFW.

Every ``morpfw.Model`` and ``morpfw.Collection`` can be attached with
your custom views or you may also override the built-in views on your
own application.

.. todo:: some basic examples on how to register your own custom views

